/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#ifndef _NO_PROTO
void             InitGlobalVar (void);
void             InitViewScale (void);
void             InitFiles (void);
void             MakeTwoDim (void);
void 		 FindScreenMaxMin(void);
void		 InitEmptySet(void);
#else
void             InitGlobalVar ();
void             InitViewScale ();
void             InitFiles ();
void             MakeTwoDim ();
void 		 FindScreenMaxMin();
void 		 InitEmptySet();
#endif
